;Filename: TMod.s
;Part: ADuC7020,ADuC7024,ADuC7026.
;Created: 01/09/2004
;Updated: 28/06/2005
;Author: Barry Broderick
;This file is in beta sampling.

#include        <ADuC702x.IAR.equ>

; TMod==========Sets mode of timer T.
; C Function prototype: int TMod(int iT, int iUp, int iHMSH);
;iT:{0,1,2,3}
;iUp:{0,1}
;iHMSH:{T_BIN,T_23H,T_255H}
; Description of Function: Configures timer T.
; User interface:
;   Set iT to desired Timer, 0 to 3 
;   Set iUp to 0 to count down else count is up.
;   Set iHMSH to the desired counter mode:
;       0 = T_HTim   -> Binary mode.
;       2 = T_23H -> 23 hour real time mode.
;       3 = T_255H   -> 255 hour real time mode.
;   Call TMod().
;       Timer 2 is stopped and the specified modes set.
;   Returns previous TCON value in r0.
; Robustness:
;  Certain features are not available for certain timers. Refer to the
;  data sheet for more information.  (T0 doesn't use TMod at all)
; Side effects: Corrupts r1, r2 and r3.

                RSEG CODE
                MODULE TMod
                PUBLIC TMod
                CODE32
                
TMod:    stmfd    sp!,{r4}
         mov      r3,#0xff0000             ;r3 = Z_BASE;
         orr      r3,r3,#0xff000000
         orr      r3,r3,r0,lsl#5           ;r3 = r0 << 5;

         ldr      r4,[r3,#Z_T0CON]         ;Load r2 with T0CON
         orr      r4,r4,r1,lsl#8           ; Lsl r0 by 8bits, OR r4
         cmp      r0,#0x03                 ;Compare r0 with 3
         beq      T3Mod                    ; if equal branch to T3Mod 
         orr      r4,r4,r2,lsl#4           ; Lsl r1 by 8bits, OR r4
        
T3Mod:   ldr      r0,[r3,#Z_T0CON]         ;Get T0CON.
         str      r4,[r3,#Z_T0CON]         ;Write to T0CON
         ldmfd    sp!,{r4}
         bx       lr

                 ENDMOD  TMod

                 END
        
